@@ -29,10 +29,10 @@
 namespace Oxygen
 {
 
-    const char* const PropertyNames::noAnimations = "_kde_no_animations";
-    const char* const PropertyNames::noWindowGrab = "_kde_no_window_grab";
-    const char* const PropertyNames::toolButtonAlignment = "_kde_toolbutton_alignment";
-    const char* const PropertyNames::netWMForceShadow( "_KDE_NET_WM_FORCE_SHADOW" );
-    const char* const PropertyNames::netWMSkipShadow( "_KDE_NET_WM_SKIP_SHADOW" );
+    const char PropertyNames::noAnimations[] = "_kde_no_animations";
+    const char PropertyNames::noWindowGrab[] = "_kde_no_window_grab";
+    const char PropertyNames::toolButtonAlignment[] = "_kde_toolbutton_alignment";
+    const char PropertyNames::netWMForceShadow[] = "_KDE_NET_WM_FORCE_SHADOW";
+    const char PropertyNames::netWMSkipShadow[] = "_KDE_NET_WM_SKIP_SHADOW";
 
 }
